@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from rest_framework_extensions.cache.mixins import CacheResponseMixin
 from rest_framework_extensions.etag.mixins import ReadOnlyETAGMixin, ETAGMixin
+from rest_framework_extensions.utils import get_rest_framework_features
 
 
 class DetailSerializerMixin(object):
@@ -30,6 +31,17 @@ class DetailSerializerMixin(object):
             return super(DetailSerializerMixin, self).get_queryset()
 
 
+class PaginateByMaxMixin(object):
+    def get_paginate_by(self, *args, **kwargs):
+        if (get_rest_framework_features()['max_paginate_by'] and
+            self.paginate_by_param and
+            self.max_paginate_by and
+            self.request.QUERY_PARAMS.get(self.paginate_by_param) == 'max'):
+            return self.max_paginate_by
+        else:
+            return super(PaginateByMaxMixin, self).get_paginate_by(*args, **kwargs)
+
+
 class ReadOnlyCacheResponseAndETAGMixin(ReadOnlyETAGMixin, CacheResponseMixin):
     pass
 
